@@ -18,8 +18,8 @@ from calcure.importers import Importer
 from calcure.dialogues import clear_line
 from calcure.screen import Screen
 from calcure.savers import TaskSaverCSV, EventSaverCSV
-from calcure.colors import initialize_colors
-from calcure.loaders import TaskLoaderCSV, TaskLoaderICS, EventLoaderCSV, EventLoaderICS, HolidayLoader, BirthdayLoader
+from calcure.colors import Color, initialize_colors
+from calcure.loaders import *
 from calcure.data import *
 from calcure.controls import *
 
@@ -41,7 +41,7 @@ else:
     from calcure.translations.en import *
 
 
-__version__ = "2.7.5"
+__version__ = "2.7.6"
 
 
 def read_items_from_user_arguments(screen, user_tasks, user_events, task_saver_csv, event_saver_csv):
@@ -248,12 +248,17 @@ class EventView(View):
     @property
     def color(self):
         """Select the color depending on the status and type"""
-        color = Color.EVENTS
-        if self.event.status == Status.IMPORTANT:
-            color = Color.IMPORTANT
-        if self.event.status == Status.UNIMPORTANT:
-            color = Color.UNIMPORTANT
-        return color
+        if self.event.calendar_number is None:
+            if self.event.status == Status.IMPORTANT:
+                return Color.IMPORTANT
+            if self.event.status == Status.UNIMPORTANT:
+                return Color.UNIMPORTANT
+            return Color.EVENTS
+        else:
+            for color in Color:
+                if color.value == Color.ICS_CALENDARS0.value + self.event.calendar_number:
+                    return color
+            return Color.EVENTS
 
     def obfuscate_info(self):
         """Obfuscate the info if privacy mode is on"""
@@ -901,16 +906,16 @@ class HelpScreenView(View):
         self.display_line(d_y + 5, d_x, MSG_SITE, Color.TITLE)
 
 
-def main(stdscr):
-    """Main function that loads the data, runs and switches screens"""
+def main(stdscr) -> None:
+    """Main function that runs and switches screens"""
 
-    # Load weather:
+    # Load the data:
     weather = Weather(cf.WEATHER_CITY)
     if cf.SHOW_WEATHER:
         sys.stdout.write(f"\r{MSG_WEATHER}")
         weather.load_from_wttr()
+    screen = Screen(stdscr, cf)
 
-    # Initialise loaders:
     event_loader_csv = EventLoaderCSV(cf)
     task_loader_csv = TaskLoaderCSV(cf)
     event_loader_ics = EventLoaderICS(cf)
@@ -918,7 +923,6 @@ def main(stdscr):
     birthday_loader = BirthdayLoader(cf)
     holiday_loader = HolidayLoader(cf)
 
-    # Load the data:
     user_events = event_loader_csv.load()
     user_tasks = task_loader_csv.load()
     user_ics_events = event_loader_ics.load()
@@ -926,12 +930,10 @@ def main(stdscr):
     holidays = holiday_loader.load()
     birthdays = birthday_loader.load()
 
-    # Initialise savers and importers:
     event_saver_csv = EventSaverCSV(user_events, cf)
     task_saver_csv = TaskSaverCSV(user_tasks, cf)
     importer = Importer(user_tasks, user_events, cf)
 
-    screen = Screen(stdscr, cf)
     read_items_from_user_arguments(screen, user_tasks, user_events, task_saver_csv, event_saver_csv)
 
     # Initialise terminal screen:
@@ -966,6 +968,8 @@ def main(stdscr):
             app_view.fill_background()
         screen.active_pane = False
 
+        # CALENDARS
+
         # Monthly (active) screen:
         if screen.state == AppState.CALENDAR and screen.calendar_state == CalState.MONTHLY:
             if screen.split and not screen.selection_mode:
@@ -990,6 +994,8 @@ def main(stdscr):
             footer_view.render()
             control_daily_screen(stdscr, user_events, screen, importer)
 
+        # JOURNAL
+
         # Journal (active) screen:
         elif screen.state == AppState.JOURNAL:
             if screen.split and not screen.selection_mode:
