@@ -1,6 +1,7 @@
 """This module contains functions that react to user input on each screen"""
 
 import curses
+import importlib
 
 # Modules:
 from calcure.configuration import cf
@@ -16,6 +17,10 @@ elif cf.LANG == "it":
     from calcure.translations.it import *
 elif cf.LANG == "br":
     from calcure.translations.br import *
+elif cf.LANG == "tr":
+    from calcure.translations.tr import *
+elif cf.LANG == "zh":
+    from calcure.translations.zh import *
 else:
     from calcure.translations.en import *
 
@@ -137,6 +142,7 @@ def control_monthly_screen(stdscr, user_events, screen, importer):
                 confirmed = ask_confirmation(stdscr, MSG_EVENT_IMP, cf.ASK_CONFIRMATIONS)
                 if confirmed:
                     importer.import_events_from_calcurse()
+                    screen.refresh_now = True
 
             # Other actions:
             if vim_style_exit(stdscr, screen):
@@ -347,7 +353,7 @@ def control_journal_screen(stdscr, user_tasks, screen, importer):
                     task_id = user_tasks.items[number].item_id
                     user_tasks.toggle_item_status(task_id, Status.NORMAL)
             if screen.key == 'v':
-                number = input_integer(stdscr, screen.y_max-2, 0, MSG_TS_LOW)
+                number = input_integer(stdscr, screen.y_max-2, 0, MSG_TS_DONE)
                 if user_tasks.is_valid_number(number):
                     task_id = user_tasks.items[number].item_id
                     user_tasks.toggle_item_status(task_id, Status.DONE)
@@ -429,10 +435,12 @@ def control_journal_screen(stdscr, user_tasks, screen, importer):
                 confirmed = ask_confirmation(stdscr, MSG_TS_IM, cf.ASK_CONFIRMATIONS)
                 if confirmed:
                     importer.import_tasks_from_calcurse()
+                    screen.refresh_now = True
             if screen.key == "W":
                 confirmed = ask_confirmation(stdscr, MSG_TS_TW, cf.ASK_CONFIRMATIONS)
                 if confirmed:
                     importer.import_tasks_from_taskwarrior()
+                    screen.refresh_now = True
 
             # Other actions:
             if vim_style_exit(stdscr, screen):
